using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace GPStoGoogleMapDesktop
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        Proj4Projection proj4;
        bool mapunitIsDD = true;

        private void TestForm_Load(object sender, EventArgs e)
        {
            proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
            proj4.ExternalProjectionParametersString = Proj4Projection.GetWgs84ParametersString();
            proj4.Open();

            ReloadMap();
        }

        private void ReloadMap()
        {
            winformsMap1.ZoomLevelSnapping = ZoomLevelSnappingMode.None;
            winformsMap1.MinimumScale = 0;
            winformsMap1.ZoomLevelSet = new GoogleMapsZoomLevelSet();
            
            winformsMap1.Overlays.Clear();

            GoogleMapsOverlay googleOverlay = new GoogleMapsOverlay(@"C:\GoogleCache", "your client id", "your private key");
            //googleOverlay.WebProxy = new System.Net.WebProxy("127.0.0.1:1080"); // You don't need this line
            googleOverlay.MapType = ThinkGeo.MapSuite.WinForms.GoogleMapsMapType.Hybrid;
            winformsMap1.Overlays.Add(googleOverlay);

            RectangleShape shape = new RectangleShape(-122.9, 45.55, -122.8, 45.45);
            if (mapunitIsDD)
            {
                winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
                winformsMap1.CurrentExtent = new RectangleShape(-123.02060015736, 45.6005019300307, -122.75149324264, 45.4119034420553);
                googleOverlay.ProjectionFromSphericalMercator = proj4;

                //winformsMap1.CurrentExtent.UpperLeftPoint.X = -123.02060015736;
                //winformsMap1.CurrentExtent.UpperLeftPoint.Y = 45.6005019300307;
                //winformsMap1.CurrentExtent.LowerRightPoint.X = -122.75149324264;
                //winformsMap1.CurrentExtent.LowerRightPoint.Y = 45.4119034420553;
            }
            else
            {
                winformsMap1.MapUnit = GeographyUnit.Meter;
                winformsMap1.CurrentExtent = proj4.ConvertToInternalProjection(new RectangleShape(-123.02060015736, 45.6005019300307, -122.75149324264, 45.4119034420553)) as RectangleShape;
                shape = proj4.ConvertToInternalProjection(shape) as RectangleShape;

                //winformsMap1.CurrentExtent.UpperLeftPoint.X = -13694590.5666002;
                //winformsMap1.CurrentExtent.UpperLeftPoint.Y = 5716558.88651489;
                //winformsMap1.CurrentExtent.LowerRightPoint.X = -13664633.7126852;
                //winformsMap1.CurrentExtent.LowerRightPoint.Y = 5686602.03259987;
            }


            LayerOverlay overlay = new LayerOverlay();
            InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 200, 200, 200));
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;            
            layer.InternalFeatures.Add(new Feature(shape));

            overlay.Layers.Add(layer);
            winformsMap1.Overlays.Add(overlay);

            winformsMap1.Refresh();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            if (button1.Text == "DecimalDegree")
            {
                button1.Text = "Meter";
                mapunitIsDD = false;
            }
            else
            {
                button1.Text = "DecimalDegree";
                mapunitIsDD = true;
            }

            ReloadMap();
        }
    }
}
